@@ -5,7 +5,7 @@
 
     Test the Sphinx class.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -88,3 +88,18 @@ def test_domain_override(app, status, warning):
     assert app.override_domain(B) is None
     raises_msg(ExtensionError, 'new domain not a subclass of registered '
                'foo domain', app.override_domain, C)
+
+
+@with_app(testroot='add_source_parser')
+def test_add_source_parser(app, status, warning):
+    assert set(app.config.source_suffix) == set(['.rst', '.md', '.test'])
+    assert set(app.config.source_parsers.keys()) == set(['.md', '.test'])
+    assert app.config.source_parsers['.md'].__name__ == 'DummyMarkdownParser'
+    assert app.config.source_parsers['.test'].__name__ == 'TestSourceParser'
+
+
+@with_app(testroot='add_source_parser-conflicts-with-users-setting')
+def test_add_source_parser_conflicts_with_users_setting(app, status, warning):
+    assert set(app.config.source_suffix) == set(['.rst', '.test'])
+    assert set(app.config.source_parsers.keys()) == set(['.test'])
+    assert app.config.source_parsers['.test'].__name__ == 'DummyTestParser'
