@@ -5,12 +5,14 @@
 
     Test all builders.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 from six import BytesIO
 
+import pickle
+from docutils import nodes
 from textwrap import dedent
 from sphinx.errors import SphinxError
 
@@ -68,7 +70,7 @@ def test_build_all():
 
     # note: no 'html' - if it's ok with dirhtml it's ok with html
     for buildername in ['dirhtml', 'singlehtml', 'latex', 'texinfo', 'pickle',
-                        'json', 'text', 'htmlhelp', 'qthelp', 'epub',
+                        'json', 'text', 'htmlhelp', 'qthelp', 'epub', 'epub3',
                         'applehelp', 'changes', 'xml', 'pseudoxml', 'man',
                         'linkcheck']:
         yield verify_build, buildername, srcdir
@@ -108,3 +110,51 @@ def test_numbered_circular_toctree(app, status, warning):
     assert (
         'circular toctree references detected, ignoring: '
         'contents <- sub <- contents') in warnings
+
+
+@with_app(buildername='dummy', testroot='image-glob')
+def test_image_glob(app, status, warning):
+    app.builder.build_all()
+
+    # index.rst
+    doctree = pickle.loads((app.doctreedir / 'index.doctree').bytes())
+
+    assert isinstance(doctree[0][1], nodes.image)
+    assert doctree[0][1]['candidates'] == {'*': 'rimg.png'}
+    assert doctree[0][1]['uri'] == 'rimg.png'
+
+    assert isinstance(doctree[0][2], nodes.figure)
+    assert isinstance(doctree[0][2][0], nodes.image)
+    assert doctree[0][2][0]['candidates'] == {'*': 'rimg.png'}
+    assert doctree[0][2][0]['uri'] == 'rimg.png'
+
+    assert isinstance(doctree[0][3], nodes.image)
+    assert doctree[0][3]['candidates'] == {'application/pdf': 'img.pdf',
+                                           'image/gif': 'img.gif',
+                                           'image/png': 'img.png'}
+    assert doctree[0][3]['uri'] == 'img.*'
+
+    assert isinstance(doctree[0][4], nodes.figure)
+    assert isinstance(doctree[0][4][0], nodes.image)
+    assert doctree[0][4][0]['candidates'] == {'application/pdf': 'img.pdf',
+                                              'image/gif': 'img.gif',
+                                              'image/png': 'img.png'}
+    assert doctree[0][4][0]['uri'] == 'img.*'
+
+    # subdir/index.rst
+    doctree = pickle.loads((app.doctreedir / 'subdir/index.doctree').bytes())
+
+    assert isinstance(doctree[0][1], nodes.image)
+    assert doctree[0][1]['candidates'] == {'*': 'subdir/rimg.png'}
+    assert doctree[0][1]['uri'] == 'subdir/rimg.png'
+
+    assert isinstance(doctree[0][2], nodes.image)
+    assert doctree[0][2]['candidates'] == {'application/pdf': 'subdir/svgimg.pdf',
+                                           'image/svg+xml': 'subdir/svgimg.svg'}
+    assert doctree[0][2]['uri'] == 'subdir/svgimg.*'
+
+    assert isinstance(doctree[0][3], nodes.figure)
+    assert isinstance(doctree[0][3][0], nodes.image)
+    assert doctree[0][3][0]['candidates'] == {'application/pdf': 'subdir/svgimg.pdf',
+                                              'image/svg+xml': 'subdir/svgimg.svg'}
+    assert doctree[0][3][0]['uri'] == 'subdir/svgimg.*'
