@@ -24,10 +24,10 @@ from test_build_html import ENV_WARNINGS
 
 
 LATEX_WARNINGS = ENV_WARNINGS + """\
-%(root)s/markup.txt:160: WARNING: unknown option: &option
+%(root)s/markup.txt:164: WARNING: unknown option: &option
 %(root)s/footnote.txt:60: WARNING: citation not found: missing
 %(root)s/images.txt:20: WARNING: no matching candidate for image URI u'foo.\\*'
-%(root)s/markup.txt:271: WARNING: Could not lex literal_block as "c". Highlighting skipped.
+%(root)s/markup.txt:285: WARNING: Could not lex literal_block as "c". Highlighting skipped.
 """
 
 if PY3:
@@ -106,6 +106,20 @@ def test_latex(app, status, warning):
     run_latex(app.outdir)
 
 
+@with_app(buildername='latex')
+def test_writer(app, status, warning):
+    app.builder.build_all()
+    result = (app.outdir / 'SphinxTests.tex').text(encoding='utf8')
+
+    assert ('\\begin{wrapfigure}{r}{0pt}\n\\centering\n'
+            '\\includegraphics{{rimg}.png}\n\\caption{figure with align option}'
+            '\\label{markup:id7}\\end{wrapfigure}' in result)
+
+    assert ('\\begin{wrapfigure}{r}{0.500\\linewidth}\n\\centering\n'
+            '\\includegraphics{{rimg}.png}\n\\caption{figure with align \\& figwidth option}'
+            '\\label{markup:id8}\\end{wrapfigure}' in result)
+
+
 @with_app(buildername='latex', freshenv=True,  # use freshenv to check warnings
           confoverrides={'latex_documents': [
               ('contents', 'SphinxTests.tex', 'Sphinx Tests Documentation',
@@ -163,10 +177,10 @@ def test_numref(app, status, warning):
     print(result)
     print(status.getvalue())
     print(warning.getvalue())
-    assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Fig. }}' in result
+    assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Fig.\\@ }}' in result
     assert '\\addto\\captionsenglish{\\renewcommand{\\tablename}{Table }}' in result
     assert '\\SetupFloatingEnvironment{literal-block}{name=Listing }' in result
-    assert '\\hyperref[index:fig1]{Fig. \\ref{index:fig1}}' in result
+    assert '\\hyperref[index:fig1]{Fig.\\@ \\ref{index:fig1}}' in result
     assert '\\hyperref[baz:fig22]{Figure\\ref{baz:fig22}}' in result
     assert '\\hyperref[index:table-1]{Table \\ref{index:table-1}}' in result
     assert '\\hyperref[baz:table22]{Table:\\ref{baz:table22}}' in result
@@ -214,11 +228,11 @@ def test_numref_with_prefix2(app, status, warning):
     print(status.getvalue())
     print(warning.getvalue())
     assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Figure:}}' in result
-    assert '\\def\\fnum@figure{\\figurename\\thefigure.}' in result
+    assert '\\def\\fnum@figure{\\figurename\\thefigure.\\@}' in result
     assert '\\addto\\captionsenglish{\\renewcommand{\\tablename}{Tab\\_}}' in result
     assert '\\def\\fnum@table{\\tablename\\thetable:}' in result
     assert '\\SetupFloatingEnvironment{literal-block}{name=Code-}' in result
-    assert '\\hyperref[index:fig1]{Figure:\\ref{index:fig1}.}' in result
+    assert '\\hyperref[index:fig1]{Figure:\\ref{index:fig1}.\\@}' in result
     assert '\\hyperref[baz:fig22]{Figure\\ref{baz:fig22}}' in result
     assert '\\hyperref[index:table-1]{Tab\\_\\ref{index:table-1}:}' in result
     assert '\\hyperref[baz:table22]{Table:\\ref{baz:table22}}' in result
@@ -268,9 +282,10 @@ def test_babel_with_no_language_settings(app, status, warning):
     assert '\\usepackage[Bjarne]{fncychap}' in result
     assert ('\\addto\\captionsenglish{\\renewcommand{\\contentsname}{Table of content}}\n'
             in result)
-    assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Fig. }}\n' in result
-    assert '\\addto\\captionsenglish{\\renewcommand{\\tablename}{Table. }}\n' in result
+    assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Fig.\\@ }}\n' in result
+    assert '\\addto\\captionsenglish{\\renewcommand{\\tablename}{Table.\\@ }}\n' in result
     assert '\\addto\\extrasenglish{\\def\\pageautorefname{page}}\n' in result
+    assert '\\shorthandoff' not in result
 
 
 @with_app(buildername='latex', testroot='latex-babel',
@@ -287,9 +302,10 @@ def test_babel_with_language_de(app, status, warning):
     assert '\\usepackage[Sonny]{fncychap}' in result
     assert ('\\addto\\captionsngerman{\\renewcommand{\\contentsname}{Table of content}}\n'
             in result)
-    assert '\\addto\\captionsngerman{\\renewcommand{\\figurename}{Fig. }}\n' in result
-    assert '\\addto\\captionsngerman{\\renewcommand{\\tablename}{Table. }}\n' in result
+    assert '\\addto\\captionsngerman{\\renewcommand{\\figurename}{Fig.\\@ }}\n' in result
+    assert '\\addto\\captionsngerman{\\renewcommand{\\tablename}{Table.\\@ }}\n' in result
     assert '\\addto\\extrasngerman{\\def\\pageautorefname{page}}\n' in result
+    assert '\\shorthandoff{"}' in result
 
 
 @with_app(buildername='latex', testroot='latex-babel',
@@ -306,9 +322,30 @@ def test_babel_with_language_ru(app, status, warning):
     assert '\\usepackage[Sonny]{fncychap}' in result
     assert ('\\addto\\captionsrussian{\\renewcommand{\\contentsname}{Table of content}}\n'
             in result)
-    assert '\\addto\\captionsrussian{\\renewcommand{\\figurename}{Fig. }}\n' in result
-    assert '\\addto\\captionsrussian{\\renewcommand{\\tablename}{Table. }}\n' in result
+    assert '\\addto\\captionsrussian{\\renewcommand{\\figurename}{Fig.\\@ }}\n' in result
+    assert '\\addto\\captionsrussian{\\renewcommand{\\tablename}{Table.\\@ }}\n' in result
     assert '\\addto\\extrasrussian{\\def\\pageautorefname{page}}\n' in result
+    assert '\\shorthandoff' not in result
+
+
+@with_app(buildername='latex', testroot='latex-babel',
+          confoverrides={'language': 'tr'})
+def test_babel_with_language_tr(app, status, warning):
+    app.builder.build_all()
+    result = (app.outdir / 'Python.tex').text(encoding='utf8')
+    print(result)
+    print(status.getvalue())
+    print(warning.getvalue())
+    assert '\\documentclass[letterpaper,10pt,turkish]{sphinxmanual}' in result
+    assert '\\usepackage{babel}' in result
+    assert '\\usepackage{times}' in result
+    assert '\\usepackage[Sonny]{fncychap}' in result
+    assert ('\\addto\\captionsturkish{\\renewcommand{\\contentsname}{Table of content}}\n'
+            in result)
+    assert '\\addto\\captionsturkish{\\renewcommand{\\figurename}{Fig.\\@ }}\n' in result
+    assert '\\addto\\captionsturkish{\\renewcommand{\\tablename}{Table.\\@ }}\n' in result
+    assert '\\addto\\extrasturkish{\\def\\pageautorefname{sayfa}}\n' in result
+    assert '\\shorthandoff{=}' in result
 
 
 @with_app(buildername='latex', testroot='latex-babel',
@@ -324,9 +361,10 @@ def test_babel_with_language_ja(app, status, warning):
     assert '\\usepackage{times}' in result
     assert '\\usepackage[Sonny]{fncychap}' not in result
     assert '\\renewcommand{\\contentsname}{Table of content}\n' in result
-    assert '\\renewcommand{\\figurename}{Fig. }\n' in result
-    assert '\\renewcommand{\\tablename}{Table. }\n' in result
+    assert '\\renewcommand{\\figurename}{Fig.\\@ }\n' in result
+    assert '\\renewcommand{\\tablename}{Table.\\@ }\n' in result
     assert u'\\def\\pageautorefname{ページ}\n' in result
+    assert '\\shorthandoff' not in result
 
 
 @with_app(buildername='latex', testroot='latex-babel',
@@ -343,9 +381,10 @@ def test_babel_with_unknown_language(app, status, warning):
     assert '\\usepackage[Sonny]{fncychap}' in result
     assert ('\\addto\\captionsenglish{\\renewcommand{\\contentsname}{Table of content}}\n'
             in result)
-    assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Fig. }}\n' in result
-    assert '\\addto\\captionsenglish{\\renewcommand{\\tablename}{Table. }}\n' in result
+    assert '\\addto\\captionsenglish{\\renewcommand{\\figurename}{Fig.\\@ }}\n' in result
+    assert '\\addto\\captionsenglish{\\renewcommand{\\tablename}{Table.\\@ }}\n' in result
     assert '\\addto\\extrasenglish{\\def\\pageautorefname{page}}\n' in result
+    assert '\\shorthandoff' not in result
 
     assert "WARNING: no Babel option known for language 'unknown'" in warning.getvalue()
 
@@ -458,21 +497,22 @@ def test_latex_show_urls_is_footnote(app, status, warning):
     assert 'First footnote: \\footnote[3]{\sphinxAtStartFootnote%\nFirst\n}' in result
     assert 'Second footnote: \\footnote[1]{\sphinxAtStartFootnote%\nSecond\n}' in result
     assert ('\\href{http://sphinx-doc.org/}{Sphinx}'
-            '\\footnote[4]{\sphinxAtStartFootnote%\nhttp://sphinx-doc.org/\n}' in result)
+            '\\footnote[4]{\sphinxAtStartFootnote%\n'
+            '\\nolinkurl{http://sphinx-doc.org/}\n}' in result)
     assert 'Third footnote: \\footnote[6]{\sphinxAtStartFootnote%\nThird\n}' in result
     assert ('\\href{http://sphinx-doc.org/~test/}{URL including tilde}'
             '\\footnote[5]{\sphinxAtStartFootnote%\n'
-            'http://sphinx-doc.org/\\textasciitilde{}test/\n}' in result)
+            '\\nolinkurl{http://sphinx-doc.org/~test/}\n}' in result)
     assert ('\\item[{\\href{http://sphinx-doc.org/}{URL in term}\\protect\\footnotemark[8]}] '
             '\\leavevmode\\footnotetext[8]{\sphinxAtStartFootnote%\n'
-            'http://sphinx-doc.org/\n}\nDescription' in result)
+            '\\nolinkurl{http://sphinx-doc.org/}\n}\nDescription' in result)
     assert ('\\item[{Footnote in term \\protect\\footnotemark[10]}] '
             '\\leavevmode\\footnotetext[10]{\sphinxAtStartFootnote%\n'
             'Footnote in term\n}\nDescription' in result)
     assert ('\\item[{\\href{http://sphinx-doc.org/}{Term in deflist}\\protect'
             '\\footnotemark[9]}] '
             '\\leavevmode\\footnotetext[9]{\sphinxAtStartFootnote%\n'
-            'http://sphinx-doc.org/\n}\nDescription' in result)
+            '\\nolinkurl{http://sphinx-doc.org/}\n}\nDescription' in result)
     assert ('\\url{https://github.com/sphinx-doc/sphinx}\n' in result)
     assert ('\\href{mailto:sphinx-dev@googlegroups.com}'
             '{sphinx-dev@googlegroups.com}\n' in result)
